@@ -566,6 +566,10 @@ gdm_slave_run (GdmDisplay *display)
 		    gdm_verify_cleanup (d);
 		    _exit (DISPLAY_REMANAGE);
 	    }
+
+	    /* return to gdm_slave_start so that the server
+	     * can be reinitted and all that kind of fun stuff. */
+	    return;
     }
 
     if (gdm_first_login)
@@ -615,6 +619,9 @@ gdm_slave_run (GdmDisplay *display)
 		    gdm_slave_greeter_ctl_no_ret (GDM_ENABLE, "");
 		    gdm_slave_greeter_ctl_no_ret (GDM_RESETOK, "");
 	    }
+	    /* Note that greet is only true if the above was no 'login',
+	     * so no need to reinit the server nor rebake cookies
+	     * nor such nonsense */
     } while (greet);
 }
 
@@ -1204,7 +1211,8 @@ run_pictures (void)
 		}
 		g_free (ret);
 
-		g_print ("%c", STX);
+		printf ("%c", STX);
+		fflush (stdout);
 
 		i = 0;
 		while ((bytes = fread (buf, sizeof (char),
@@ -3050,10 +3058,11 @@ gdm_slave_greeter_ctl (char cmd, const char *str)
     check_notifies_immediately ++;
 
     if ( ! ve_string_empty (str)) {
-	    g_print ("%c%c%s\n", STX, cmd, str);
+	    printf ("%c%c%s\n", STX, cmd, str);
     } else {
-	    g_print ("%c%c\n", STX, cmd);
+	    printf ("%c%c\n", STX, cmd);
     }
+    fflush (stdout);
 
     /* Skip random junk that might have accumulated */
     do {
