@@ -55,10 +55,11 @@
  */
 
 #include <config.h> 
-#include <gnome.h>
+#include <libgnome/libgnome.h>
 
 #ifdef HAVE_LIBXDMCP
 #include <stdio.h>
+#include <unistd.h>
 #include <time.h>
 #include <stdlib.h>
 #include <syslog.h>
@@ -96,7 +97,6 @@
 #include "choose.h"
 #include "xdmcp.h"
 
-static const gchar RCSid[]="$Id: xdmcp.c,v 1.45 2001/10/28 19:13:42 jirka Exp $";
 gint pending = 0;
 
 #ifdef HAVE_LIBXDMCP
@@ -105,12 +105,14 @@ gint pending = 0;
 gint allow_severity = LOG_INFO;
 gint deny_severity = LOG_WARNING;
 
-static gint gdm_xdmcpfd = -1;
+int gdm_xdmcpfd = -1;
+
 static guint xdmcp_source = 0;
 static gint globsessid;
 static gchar *sysid;
 static ARRAY8 servhost;
 static XdmcpBuffer buf;
+static gboolean initted = FALSE;
 
 extern GSList *displays;
 extern gint sessions;
@@ -231,23 +233,29 @@ gdm_xdmcp_init (void)
     struct sockaddr_in serv_sa = {0};
     gchar hostbuf[256];
     struct utsname name;
+
+    if ( ! GdmXdmcp)
+	    return TRUE;
     
     globsessid = time (NULL);
     
     /* Fetch and store local hostname in XDMCP friendly format */
     if (gethostname (hostbuf, 255) != 0) {
 	gdm_error (_("gdm_xdmcp_init: Could not get server hostname: %s!"), strerror (errno));
-	GdmXdmcp = FALSE;
-	return FALSE;
+	strcmp (hostbuf, "localhost.localdomain");
+    }
+
+    if ( ! initted) {
+	    uname (&name);
+	    sysid = g_strconcat (name.sysname, " ", name.release, NULL);
+
+	    servhost.data = g_strdup (hostbuf);
+	    servhost.length = strlen (servhost.data);
+	    
+	    initted = TRUE;
     }
     
-    uname (&name);
-    sysid = g_strconcat (name.sysname, " ", name.release, NULL);
-
-    servhost.data = g_strdup (hostbuf);
-    servhost.length = strlen (servhost.data);
-    
-    gdm_debug ("Start up on host %s, port %d", hostbuf, GdmPort);
+    gdm_debug ("XDMCP: Start up on host %s, port %d", hostbuf, GdmPort);
     
     /* Open socket for communications */
     gdm_xdmcpfd = socket (AF_INET, SOCK_DGRAM, 0); /* UDP */
@@ -279,6 +287,8 @@ gdm_xdmcp_run (void)
 	GIOChannel *xdmcpchan;
 
 	xdmcpchan = g_io_channel_unix_new (gdm_xdmcpfd);
+	g_io_channel_set_buffered (xdmcpchan, FALSE);
+
 	xdmcp_source = g_io_add_watch_full
 		(xdmcpchan, G_PRIORITY_DEFAULT,
 		 G_IO_IN|G_IO_PRI|G_IO_ERR|G_IO_HUP|G_IO_NVAL,
@@ -766,6 +776,7 @@ gdm_xdmcp_send_willing (struct sockaddr_in *clnt_sa)
 		    last_status = g_strdup (sysid);
 	    }
 	    last_willing = time (NULL);
+	    g_free (bin);
     }
 
     if ( ! gdm_is_local_addr (&(clnt_sa->sin_addr)) &&
@@ -1540,6 +1551,9 @@ gdm_xdmcp_display_alloc (struct in_addr *addr, const char *hostname, gint displa
 			       displaynum);
     d->hostname = g_strdup (hostname);
     memcpy (&d->addr, addr, sizeof (struct in_addr));
+
+    d->slave_notify_fd = -1;
+    d->master_notify_fd = -1;
     
     /* Secure display with cookie */
     if (! gdm_auth_secure_display (d))
